/***************************************************************************//**
* \file IDAC_LS.h
* \version 1.10
*
* \brief
*  This file provides constants and parameter values for the IDAC7
*  component.
*
********************************************************************************
* \copyright
* Copyright 2017, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_IDAC7_IDAC_LS_H)
#define CY_IDAC7_IDAC_LS_H

#include "cyfitter.h"
#include "CyLib.h"


/***************************************
*   Conditional Compilation Parameters
****************************************/

#define IDAC_LS_CURRENT_VALUE        ((uint32)64)
#define IDAC_LS_CURRENT_RANGE        ((uint32)14)
#define IDAC_LS_CURRENT_POLARITY     ((uint32)0)


/**************************************
*    Enumerated Types and Parameters
**************************************/

/* IDAC7 polarity setting constants */
#define IDAC_LS__POL_SOURCE 0
#define IDAC_LS__POL_SINK 1


/* IDAC7 range setting constants */
#define IDAC_LS__RNG_4_76UA 4
#define IDAC_LS__RNG_9_52UA 12
#define IDAC_LS__RNG_38_1UA 5
#define IDAC_LS__RNG_76_2UA 13
#define IDAC_LS__RNG_304_8UA 6
#define IDAC_LS__RNG_609_6UA 14
#define IDAC_LS__RNG_152_4UA 7


/* IDAC7 polarity setting definitions */
#define IDAC_LS_POL_SOURCE     ((uint32)IDAC_LS__POL_SOURCE)
#define IDAC_LS_POL_SINK       ((uint32)IDAC_LS__POL_SINK)

/* IDAC7 range setting definitions */
#define IDAC_LS_RNG_4_76UA     ((uint32)IDAC_LS__RNG_4_76UA)
#define IDAC_LS_RNG_9_52UA     ((uint32)IDAC_LS__RNG_9_52UA)
#define IDAC_LS_RNG_38_1UA     ((uint32)IDAC_LS__RNG_38_1UA)
#define IDAC_LS_RNG_76_2UA     ((uint32)IDAC_LS__RNG_76_2UA)
#define IDAC_LS_RNG_152_4UA    ((uint32)IDAC_LS__RNG_152_4UA)
#define IDAC_LS_RNG_304_8UA    ((uint32)IDAC_LS__RNG_304_8UA)
#define IDAC_LS_RNG_609_6UA    ((uint32)IDAC_LS__RNG_609_6UA)


/***************************************
*        Function Prototypes
***************************************/
/**
* \addtogroup group_general
* @{
*/
void IDAC_LS_Init(void);
void IDAC_LS_Enable(void);
void IDAC_LS_Start(void);
void IDAC_LS_Stop(void);
void IDAC_LS_SetValue(uint32 current);
void IDAC_LS_SetPolarity(uint32 polarity);
void IDAC_LS_SetRange(uint32 range);
/** @} group_general */

/**
* \addtogroup group_power
* @{
*/
void IDAC_LS_Sleep(void);
void IDAC_LS_Wakeup(void);
/** @} power */


/***************************************
*           Global Variables
***************************************/
/**
* \addtogroup group_globals
* @{
*/
extern uint32 IDAC_LS_initVar;
/** @} globals */


/***************************************
*            API Constants
***************************************/

/* CSD Config register */
#define IDAC_LS_CSD_CONFIG_ENABLE_POS    ((uint32)31u)
#define IDAC_LS_CSD_CONFIG_SENSE_EN_POS  ((uint32)12u)
#define IDAC_LS_CSD_CONFIG_LOW_VDDA_POS  ((uint32)3u)
#define IDAC_LS_CSD_CONFIG_SENSE_EN      ((uint32)(0x1u) <<  IDAC_LS_CSD_CONFIG_SENSE_EN_POS)
#define IDAC_LS_CSD_CONFIG_ENABLE        ((uint32)(0x1u) <<  IDAC_LS_CSD_CONFIG_ENABLE_POS)
#define IDAC_LS_CSD_CONFIG_LOW_VDDA      ((uint32)(0x1u) <<  IDAC_LS_CSD_CONFIG_LOW_VDDA_POS)

/* IDAC register */
#define IDAC_LS_CURRENT_VALUE_POS        ((uint32)0u)
#define IDAC_LS_POLY_DYN_POS             ((uint32)7u)
#define IDAC_LS_POLARITY_POS             ((uint32)8u)
#define IDAC_LS_LEG1_MODE_POS            ((uint32)16u)
#define IDAC_LS_LEG2_MODE_POS            ((uint32)18u)
#define IDAC_LS_DSI_CTRL_EN_POS          ((uint32)21u)
#define IDAC_LS_RANGE_POS                ((uint32)22u)
#define IDAC_LS_LEG1_EN_POS              ((uint32)24u)
#define IDAC_LS_LEG2_EN_POS              ((uint32)25u)

#define IDAC_LS_CURRENT_VALUE_MASK       ((uint32)(0x7Fu)    <<  IDAC_LS_CURRENT_VALUE_POS)
#define IDAC_LS_POLARITY_MASK            ((uint32)(0x3u)     <<  IDAC_LS_POLARITY_POS)
#define IDAC_LS_POLY_DYN                 ((uint32)(0x1u)     <<  IDAC_LS_POLY_DYN_POS)
#define IDAC_LS_LEG1_MODE_MASK           ((uint32)(0x3u)     <<  IDAC_LS_LEG1_MODE_POS)
#define IDAC_LS_LEG2_MODE_MASK           ((uint32)(0x3u)     <<  IDAC_LS_LEG2_MODE_POS)
#define IDAC_LS_DSI_CTRL_EN              ((uint32)(0x1u)     <<  IDAC_LS_DSI_CTRL_EN_POS)
#define IDAC_LS_RANGE_MASK               ((uint32)(0x3u)     <<  IDAC_LS_RANGE_POS)
#define IDAC_LS_LEG1_EN                  ((uint32)(0x1u)     <<  IDAC_LS_LEG1_EN_POS)
#define IDAC_LS_LEG2_EN                  ((uint32)(0x1u)     <<  IDAC_LS_LEG2_EN_POS)

/* Creator-global defines */
#define IDAC_LS_2000_MV                  (2000u)

#ifdef CYDEV_VDDA_MV
    #define IDAC_LS_CYDEV_VDDA_MV        (CYDEV_VDDA_MV)
#else
    #ifdef CYDEV_VDD_MV
        #define IDAC_LS_CYDEV_VDDA_MV    (CYDEV_VDD_MV)
    #endif
#endif

#if defined(CYIPBLOCK_m0s8csdv2_VERSION)
    #define IDAC_LS_M0S8CSDV2_BLOCK_VER  (CYIPBLOCK_m0s8csdv2_VERSION)
#else
    #define IDAC_LS_M0S8CSDV2_BLOCK_VER  (0u)
#endif /* (CYIPBLOCK_m0s8csdv2_VERSION) */

#define IDAC_LS_S8CSDV2_VER_2            (2u)

#if ((IDAC_LS_2000_MV > IDAC_LS_CYDEV_VDDA_MV) &&\
     (IDAC_LS_S8CSDV2_VER_2 == IDAC_LS_M0S8CSDV2_BLOCK_VER))
     #define IDAC_LS_IDAC_EN_CONFIG      (IDAC_LS_CSD_CONFIG_ENABLE |\
                                                   IDAC_LS_CSD_CONFIG_SENSE_EN |\
                                                   IDAC_LS_CSD_CONFIG_LOW_VDDA)
#else
     #define IDAC_LS_IDAC_EN_CONFIG      (IDAC_LS_CSD_CONFIG_ENABLE |\
                                                   IDAC_LS_CSD_CONFIG_SENSE_EN)
#endif /* (IDAC_LS_2000_MV > IDAC_LS_CYDEV_VDDA_MV) */

/***************************************
*        Registers
***************************************/

#define IDAC_LS_CSD_CONTROL_REG    (*(reg32 *)IDAC_LS_cy_psoc4_idac__CONFIG)
#define IDAC_LS_CSD_CONTROL_PTR    ( (reg32 *)IDAC_LS_cy_psoc4_idac__CONFIG)

#define IDAC_LS_IDAC_CONTROL_REG   (*(reg32 *)IDAC_LS_cy_psoc4_idac__IDAC)
#define IDAC_LS_IDAC_CONTROL_PTR   ( (reg32 *)IDAC_LS_cy_psoc4_idac__IDAC)

#endif /* CY_IDAC7_IDAC_LS_H */


/* [] END OF FILE */
