/*******************************************************************************
* File Name: LS_SINE.c  
* Version 2.20
*
* Description:
*  This file contains APIs to set up the Pins component for low power modes.
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "LS_SINE.h"

static LS_SINE_BACKUP_STRUCT  LS_SINE_backup = {0u, 0u, 0u};


/*******************************************************************************
* Function Name: LS_SINE_Sleep
****************************************************************************//**
*
* \brief Stores the pin configuration and prepares the pin for entering chip 
*  deep-sleep/hibernate modes. This function applies only to SIO and USBIO pins.
*  It should not be called for GPIO or GPIO_OVT pins.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None 
*  
* \sideeffect
*  For SIO pins, this function configures the pin input threshold to CMOS and
*  drive level to Vddio. This is needed for SIO pins when in device 
*  deep-sleep/hibernate modes.
*
* \funcusage
*  \snippet LS_SINE_SUT.c usage_LS_SINE_Sleep_Wakeup
*******************************************************************************/
void LS_SINE_Sleep(void)
{
    #if defined(LS_SINE__PC)
        LS_SINE_backup.pcState = LS_SINE_PC;
    #else
        #if (CY_PSOC4_4200L)
            /* Save the regulator state and put the PHY into suspend mode */
            LS_SINE_backup.usbState = LS_SINE_CR1_REG;
            LS_SINE_USB_POWER_REG |= LS_SINE_USBIO_ENTER_SLEEP;
            LS_SINE_CR1_REG &= LS_SINE_USBIO_CR1_OFF;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(LS_SINE__SIO)
        LS_SINE_backup.sioState = LS_SINE_SIO_REG;
        /* SIO requires unregulated output buffer and single ended input buffer */
        LS_SINE_SIO_REG &= (uint32)(~LS_SINE_SIO_LPM_MASK);
    #endif  
}


/*******************************************************************************
* Function Name: LS_SINE_Wakeup
****************************************************************************//**
*
* \brief Restores the pin configuration that was saved during Pin_Sleep(). This 
* function applies only to SIO and USBIO pins. It should not be called for
* GPIO or GPIO_OVT pins.
*
* For USBIO pins, the wakeup is only triggered for falling edge interrupts.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None
*  
* \funcusage
*  Refer to LS_SINE_Sleep() for an example usage.
*******************************************************************************/
void LS_SINE_Wakeup(void)
{
    #if defined(LS_SINE__PC)
        LS_SINE_PC = LS_SINE_backup.pcState;
    #else
        #if (CY_PSOC4_4200L)
            /* Restore the regulator state and come out of suspend mode */
            LS_SINE_USB_POWER_REG &= LS_SINE_USBIO_EXIT_SLEEP_PH1;
            LS_SINE_CR1_REG = LS_SINE_backup.usbState;
            LS_SINE_USB_POWER_REG &= LS_SINE_USBIO_EXIT_SLEEP_PH2;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(LS_SINE__SIO)
        LS_SINE_SIO_REG = LS_SINE_backup.sioState;
    #endif
}


/* [] END OF FILE */
