/*******************************************************************************
* File Name: PRS_LSB.h
* Version 2.10
*
* Description:
*  This file provides constants and parameter values for the PRS_LSB
*  component.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_TCPWM_PRS_LSB_H)
#define CY_TCPWM_PRS_LSB_H


#include "CyLib.h"
#include "cytypes.h"
#include "cyfitter.h"


/*******************************************************************************
* Internal Type defines
*******************************************************************************/

/* Structure to save state before go to sleep */
typedef struct
{
    uint8  enableState;
} PRS_LSB_BACKUP_STRUCT;


/*******************************************************************************
* Variables
*******************************************************************************/
extern uint8  PRS_LSB_initVar;


/***************************************
*   Conditional Compilation Parameters
****************************************/

#define PRS_LSB_CY_TCPWM_V2                    (CYIPBLOCK_m0s8tcpwm_VERSION == 2u)
#define PRS_LSB_CY_TCPWM_4000                  (CY_PSOC4_4000)

/* TCPWM Configuration */
#define PRS_LSB_CONFIG                         (7lu)

/* Quad Mode */
/* Parameters */
#define PRS_LSB_QUAD_ENCODING_MODES            (0lu)
#define PRS_LSB_QUAD_AUTO_START                (1lu)

/* Signal modes */
#define PRS_LSB_QUAD_INDEX_SIGNAL_MODE         (0lu)
#define PRS_LSB_QUAD_PHIA_SIGNAL_MODE          (3lu)
#define PRS_LSB_QUAD_PHIB_SIGNAL_MODE          (3lu)
#define PRS_LSB_QUAD_STOP_SIGNAL_MODE          (0lu)

/* Signal present */
#define PRS_LSB_QUAD_INDEX_SIGNAL_PRESENT      (0lu)
#define PRS_LSB_QUAD_STOP_SIGNAL_PRESENT       (0lu)

/* Interrupt Mask */
#define PRS_LSB_QUAD_INTERRUPT_MASK            (1lu)

/* Timer/Counter Mode */
/* Parameters */
#define PRS_LSB_TC_RUN_MODE                    (0lu)
#define PRS_LSB_TC_COUNTER_MODE                (0lu)
#define PRS_LSB_TC_COMP_CAP_MODE               (2lu)
#define PRS_LSB_TC_PRESCALER                   (0lu)

/* Signal modes */
#define PRS_LSB_TC_RELOAD_SIGNAL_MODE          (0lu)
#define PRS_LSB_TC_COUNT_SIGNAL_MODE           (3lu)
#define PRS_LSB_TC_START_SIGNAL_MODE           (0lu)
#define PRS_LSB_TC_STOP_SIGNAL_MODE            (0lu)
#define PRS_LSB_TC_CAPTURE_SIGNAL_MODE         (0lu)

/* Signal present */
#define PRS_LSB_TC_RELOAD_SIGNAL_PRESENT       (0lu)
#define PRS_LSB_TC_COUNT_SIGNAL_PRESENT        (0lu)
#define PRS_LSB_TC_START_SIGNAL_PRESENT        (0lu)
#define PRS_LSB_TC_STOP_SIGNAL_PRESENT         (0lu)
#define PRS_LSB_TC_CAPTURE_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define PRS_LSB_TC_INTERRUPT_MASK              (1lu)

/* PWM Mode */
/* Parameters */
#define PRS_LSB_PWM_KILL_EVENT                 (0lu)
#define PRS_LSB_PWM_STOP_EVENT                 (0lu)
#define PRS_LSB_PWM_MODE                       (6lu)
#define PRS_LSB_PWM_OUT_N_INVERT               (0lu)
#define PRS_LSB_PWM_OUT_INVERT                 (0lu)
#define PRS_LSB_PWM_ALIGN                      (0lu)
#define PRS_LSB_PWM_RUN_MODE                   (0lu)
#define PRS_LSB_PWM_DEAD_TIME_CYCLE            (0lu)
#define PRS_LSB_PWM_PRESCALER                  (0lu)

/* Signal modes */
#define PRS_LSB_PWM_RELOAD_SIGNAL_MODE         (0lu)
#define PRS_LSB_PWM_COUNT_SIGNAL_MODE          (3lu)
#define PRS_LSB_PWM_START_SIGNAL_MODE          (0lu)
#define PRS_LSB_PWM_STOP_SIGNAL_MODE           (0lu)
#define PRS_LSB_PWM_SWITCH_SIGNAL_MODE         (0lu)

/* Signal present */
#define PRS_LSB_PWM_RELOAD_SIGNAL_PRESENT      (0lu)
#define PRS_LSB_PWM_COUNT_SIGNAL_PRESENT       (0lu)
#define PRS_LSB_PWM_START_SIGNAL_PRESENT       (0lu)
#define PRS_LSB_PWM_STOP_SIGNAL_PRESENT        (0lu)
#define PRS_LSB_PWM_SWITCH_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define PRS_LSB_PWM_INTERRUPT_MASK             (0lu)


/***************************************
*    Initial Parameter Constants
***************************************/

/* Timer/Counter Mode */
#define PRS_LSB_TC_PERIOD_VALUE                (65535lu)
#define PRS_LSB_TC_COMPARE_VALUE               (65535lu)
#define PRS_LSB_TC_COMPARE_BUF_VALUE           (65535lu)
#define PRS_LSB_TC_COMPARE_SWAP                (0lu)

/* PWM Mode */
#define PRS_LSB_PWM_PERIOD_VALUE               (1023lu)
#define PRS_LSB_PWM_PERIOD_BUF_VALUE           (65535lu)
#define PRS_LSB_PWM_PERIOD_SWAP                (0lu)
#define PRS_LSB_PWM_COMPARE_VALUE              (256lu)
#define PRS_LSB_PWM_COMPARE_BUF_VALUE          (65535lu)
#define PRS_LSB_PWM_COMPARE_SWAP               (0lu)


/***************************************
*    Enumerated Types and Parameters
***************************************/

#define PRS_LSB__LEFT 0
#define PRS_LSB__RIGHT 1
#define PRS_LSB__CENTER 2
#define PRS_LSB__ASYMMETRIC 3

#define PRS_LSB__X1 0
#define PRS_LSB__X2 1
#define PRS_LSB__X4 2

#define PRS_LSB__PWM 4
#define PRS_LSB__PWM_DT 5
#define PRS_LSB__PWM_PR 6

#define PRS_LSB__INVERSE 1
#define PRS_LSB__DIRECT 0

#define PRS_LSB__CAPTURE 2
#define PRS_LSB__COMPARE 0

#define PRS_LSB__TRIG_LEVEL 3
#define PRS_LSB__TRIG_RISING 0
#define PRS_LSB__TRIG_FALLING 1
#define PRS_LSB__TRIG_BOTH 2

#define PRS_LSB__INTR_MASK_TC 1
#define PRS_LSB__INTR_MASK_CC_MATCH 2
#define PRS_LSB__INTR_MASK_NONE 0
#define PRS_LSB__INTR_MASK_TC_CC 3

#define PRS_LSB__UNCONFIG 8
#define PRS_LSB__TIMER 1
#define PRS_LSB__QUAD 3
#define PRS_LSB__PWM_SEL 7

#define PRS_LSB__COUNT_UP 0
#define PRS_LSB__COUNT_DOWN 1
#define PRS_LSB__COUNT_UPDOWN0 2
#define PRS_LSB__COUNT_UPDOWN1 3


/* Prescaler */
#define PRS_LSB_PRESCALE_DIVBY1                ((uint32)(0u << PRS_LSB_PRESCALER_SHIFT))
#define PRS_LSB_PRESCALE_DIVBY2                ((uint32)(1u << PRS_LSB_PRESCALER_SHIFT))
#define PRS_LSB_PRESCALE_DIVBY4                ((uint32)(2u << PRS_LSB_PRESCALER_SHIFT))
#define PRS_LSB_PRESCALE_DIVBY8                ((uint32)(3u << PRS_LSB_PRESCALER_SHIFT))
#define PRS_LSB_PRESCALE_DIVBY16               ((uint32)(4u << PRS_LSB_PRESCALER_SHIFT))
#define PRS_LSB_PRESCALE_DIVBY32               ((uint32)(5u << PRS_LSB_PRESCALER_SHIFT))
#define PRS_LSB_PRESCALE_DIVBY64               ((uint32)(6u << PRS_LSB_PRESCALER_SHIFT))
#define PRS_LSB_PRESCALE_DIVBY128              ((uint32)(7u << PRS_LSB_PRESCALER_SHIFT))

/* TCPWM set modes */
#define PRS_LSB_MODE_TIMER_COMPARE             ((uint32)(PRS_LSB__COMPARE         <<  \
                                                                  PRS_LSB_MODE_SHIFT))
#define PRS_LSB_MODE_TIMER_CAPTURE             ((uint32)(PRS_LSB__CAPTURE         <<  \
                                                                  PRS_LSB_MODE_SHIFT))
#define PRS_LSB_MODE_QUAD                      ((uint32)(PRS_LSB__QUAD            <<  \
                                                                  PRS_LSB_MODE_SHIFT))
#define PRS_LSB_MODE_PWM                       ((uint32)(PRS_LSB__PWM             <<  \
                                                                  PRS_LSB_MODE_SHIFT))
#define PRS_LSB_MODE_PWM_DT                    ((uint32)(PRS_LSB__PWM_DT          <<  \
                                                                  PRS_LSB_MODE_SHIFT))
#define PRS_LSB_MODE_PWM_PR                    ((uint32)(PRS_LSB__PWM_PR          <<  \
                                                                  PRS_LSB_MODE_SHIFT))

/* Quad Modes */
#define PRS_LSB_MODE_X1                        ((uint32)(PRS_LSB__X1              <<  \
                                                                  PRS_LSB_QUAD_MODE_SHIFT))
#define PRS_LSB_MODE_X2                        ((uint32)(PRS_LSB__X2              <<  \
                                                                  PRS_LSB_QUAD_MODE_SHIFT))
#define PRS_LSB_MODE_X4                        ((uint32)(PRS_LSB__X4              <<  \
                                                                  PRS_LSB_QUAD_MODE_SHIFT))

/* Counter modes */
#define PRS_LSB_COUNT_UP                       ((uint32)(PRS_LSB__COUNT_UP        <<  \
                                                                  PRS_LSB_UPDOWN_SHIFT))
#define PRS_LSB_COUNT_DOWN                     ((uint32)(PRS_LSB__COUNT_DOWN      <<  \
                                                                  PRS_LSB_UPDOWN_SHIFT))
#define PRS_LSB_COUNT_UPDOWN0                  ((uint32)(PRS_LSB__COUNT_UPDOWN0   <<  \
                                                                  PRS_LSB_UPDOWN_SHIFT))
#define PRS_LSB_COUNT_UPDOWN1                  ((uint32)(PRS_LSB__COUNT_UPDOWN1   <<  \
                                                                  PRS_LSB_UPDOWN_SHIFT))

/* PWM output invert */
#define PRS_LSB_INVERT_LINE                    ((uint32)(PRS_LSB__INVERSE         <<  \
                                                                  PRS_LSB_INV_OUT_SHIFT))
#define PRS_LSB_INVERT_LINE_N                  ((uint32)(PRS_LSB__INVERSE         <<  \
                                                                  PRS_LSB_INV_COMPL_OUT_SHIFT))

/* Trigger modes */
#define PRS_LSB_TRIG_RISING                    ((uint32)PRS_LSB__TRIG_RISING)
#define PRS_LSB_TRIG_FALLING                   ((uint32)PRS_LSB__TRIG_FALLING)
#define PRS_LSB_TRIG_BOTH                      ((uint32)PRS_LSB__TRIG_BOTH)
#define PRS_LSB_TRIG_LEVEL                     ((uint32)PRS_LSB__TRIG_LEVEL)

/* Interrupt mask */
#define PRS_LSB_INTR_MASK_TC                   ((uint32)PRS_LSB__INTR_MASK_TC)
#define PRS_LSB_INTR_MASK_CC_MATCH             ((uint32)PRS_LSB__INTR_MASK_CC_MATCH)

/* PWM Output Controls */
#define PRS_LSB_CC_MATCH_SET                   (0x00u)
#define PRS_LSB_CC_MATCH_CLEAR                 (0x01u)
#define PRS_LSB_CC_MATCH_INVERT                (0x02u)
#define PRS_LSB_CC_MATCH_NO_CHANGE             (0x03u)
#define PRS_LSB_OVERLOW_SET                    (0x00u)
#define PRS_LSB_OVERLOW_CLEAR                  (0x04u)
#define PRS_LSB_OVERLOW_INVERT                 (0x08u)
#define PRS_LSB_OVERLOW_NO_CHANGE              (0x0Cu)
#define PRS_LSB_UNDERFLOW_SET                  (0x00u)
#define PRS_LSB_UNDERFLOW_CLEAR                (0x10u)
#define PRS_LSB_UNDERFLOW_INVERT               (0x20u)
#define PRS_LSB_UNDERFLOW_NO_CHANGE            (0x30u)

/* PWM Align */
#define PRS_LSB_PWM_MODE_LEFT                  (PRS_LSB_CC_MATCH_CLEAR        |   \
                                                         PRS_LSB_OVERLOW_SET           |   \
                                                         PRS_LSB_UNDERFLOW_NO_CHANGE)
#define PRS_LSB_PWM_MODE_RIGHT                 (PRS_LSB_CC_MATCH_SET          |   \
                                                         PRS_LSB_OVERLOW_NO_CHANGE     |   \
                                                         PRS_LSB_UNDERFLOW_CLEAR)
#define PRS_LSB_PWM_MODE_ASYM                  (PRS_LSB_CC_MATCH_INVERT       |   \
                                                         PRS_LSB_OVERLOW_SET           |   \
                                                         PRS_LSB_UNDERFLOW_CLEAR)

#if (PRS_LSB_CY_TCPWM_V2)
    #if(PRS_LSB_CY_TCPWM_4000)
        #define PRS_LSB_PWM_MODE_CENTER                (PRS_LSB_CC_MATCH_INVERT       |   \
                                                                 PRS_LSB_OVERLOW_NO_CHANGE     |   \
                                                                 PRS_LSB_UNDERFLOW_CLEAR)
    #else
        #define PRS_LSB_PWM_MODE_CENTER                (PRS_LSB_CC_MATCH_INVERT       |   \
                                                                 PRS_LSB_OVERLOW_SET           |   \
                                                                 PRS_LSB_UNDERFLOW_CLEAR)
    #endif /* (PRS_LSB_CY_TCPWM_4000) */
#else
    #define PRS_LSB_PWM_MODE_CENTER                (PRS_LSB_CC_MATCH_INVERT       |   \
                                                             PRS_LSB_OVERLOW_NO_CHANGE     |   \
                                                             PRS_LSB_UNDERFLOW_CLEAR)
#endif /* (PRS_LSB_CY_TCPWM_NEW) */

/* Command operations without condition */
#define PRS_LSB_CMD_CAPTURE                    (0u)
#define PRS_LSB_CMD_RELOAD                     (8u)
#define PRS_LSB_CMD_STOP                       (16u)
#define PRS_LSB_CMD_START                      (24u)

/* Status */
#define PRS_LSB_STATUS_DOWN                    (1u)
#define PRS_LSB_STATUS_RUNNING                 (2u)


/***************************************
*        Function Prototypes
****************************************/

void   PRS_LSB_Init(void);
void   PRS_LSB_Enable(void);
void   PRS_LSB_Start(void);
void   PRS_LSB_Stop(void);

void   PRS_LSB_SetMode(uint32 mode);
void   PRS_LSB_SetCounterMode(uint32 counterMode);
void   PRS_LSB_SetPWMMode(uint32 modeMask);
void   PRS_LSB_SetQDMode(uint32 qdMode);

void   PRS_LSB_SetPrescaler(uint32 prescaler);
void   PRS_LSB_TriggerCommand(uint32 mask, uint32 command);
void   PRS_LSB_SetOneShot(uint32 oneShotEnable);
uint32 PRS_LSB_ReadStatus(void);

void   PRS_LSB_SetPWMSyncKill(uint32 syncKillEnable);
void   PRS_LSB_SetPWMStopOnKill(uint32 stopOnKillEnable);
void   PRS_LSB_SetPWMDeadTime(uint32 deadTime);
void   PRS_LSB_SetPWMInvert(uint32 mask);

void   PRS_LSB_SetInterruptMode(uint32 interruptMask);
uint32 PRS_LSB_GetInterruptSourceMasked(void);
uint32 PRS_LSB_GetInterruptSource(void);
void   PRS_LSB_ClearInterrupt(uint32 interruptMask);
void   PRS_LSB_SetInterrupt(uint32 interruptMask);

void   PRS_LSB_WriteCounter(uint32 count);
uint32 PRS_LSB_ReadCounter(void);

uint32 PRS_LSB_ReadCapture(void);
uint32 PRS_LSB_ReadCaptureBuf(void);

void   PRS_LSB_WritePeriod(uint32 period);
uint32 PRS_LSB_ReadPeriod(void);
void   PRS_LSB_WritePeriodBuf(uint32 periodBuf);
uint32 PRS_LSB_ReadPeriodBuf(void);

void   PRS_LSB_WriteCompare(uint32 compare);
uint32 PRS_LSB_ReadCompare(void);
void   PRS_LSB_WriteCompareBuf(uint32 compareBuf);
uint32 PRS_LSB_ReadCompareBuf(void);

void   PRS_LSB_SetPeriodSwap(uint32 swapEnable);
void   PRS_LSB_SetCompareSwap(uint32 swapEnable);

void   PRS_LSB_SetCaptureMode(uint32 triggerMode);
void   PRS_LSB_SetReloadMode(uint32 triggerMode);
void   PRS_LSB_SetStartMode(uint32 triggerMode);
void   PRS_LSB_SetStopMode(uint32 triggerMode);
void   PRS_LSB_SetCountMode(uint32 triggerMode);

void   PRS_LSB_SaveConfig(void);
void   PRS_LSB_RestoreConfig(void);
void   PRS_LSB_Sleep(void);
void   PRS_LSB_Wakeup(void);


/***************************************
*             Registers
***************************************/

#define PRS_LSB_BLOCK_CONTROL_REG              (*(reg32 *) PRS_LSB_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define PRS_LSB_BLOCK_CONTROL_PTR              ( (reg32 *) PRS_LSB_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define PRS_LSB_COMMAND_REG                    (*(reg32 *) PRS_LSB_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define PRS_LSB_COMMAND_PTR                    ( (reg32 *) PRS_LSB_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define PRS_LSB_INTRRUPT_CAUSE_REG             (*(reg32 *) PRS_LSB_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define PRS_LSB_INTRRUPT_CAUSE_PTR             ( (reg32 *) PRS_LSB_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define PRS_LSB_CONTROL_REG                    (*(reg32 *) PRS_LSB_cy_m0s8_tcpwm_1__CTRL )
#define PRS_LSB_CONTROL_PTR                    ( (reg32 *) PRS_LSB_cy_m0s8_tcpwm_1__CTRL )
#define PRS_LSB_STATUS_REG                     (*(reg32 *) PRS_LSB_cy_m0s8_tcpwm_1__STATUS )
#define PRS_LSB_STATUS_PTR                     ( (reg32 *) PRS_LSB_cy_m0s8_tcpwm_1__STATUS )
#define PRS_LSB_COUNTER_REG                    (*(reg32 *) PRS_LSB_cy_m0s8_tcpwm_1__COUNTER )
#define PRS_LSB_COUNTER_PTR                    ( (reg32 *) PRS_LSB_cy_m0s8_tcpwm_1__COUNTER )
#define PRS_LSB_COMP_CAP_REG                   (*(reg32 *) PRS_LSB_cy_m0s8_tcpwm_1__CC )
#define PRS_LSB_COMP_CAP_PTR                   ( (reg32 *) PRS_LSB_cy_m0s8_tcpwm_1__CC )
#define PRS_LSB_COMP_CAP_BUF_REG               (*(reg32 *) PRS_LSB_cy_m0s8_tcpwm_1__CC_BUFF )
#define PRS_LSB_COMP_CAP_BUF_PTR               ( (reg32 *) PRS_LSB_cy_m0s8_tcpwm_1__CC_BUFF )
#define PRS_LSB_PERIOD_REG                     (*(reg32 *) PRS_LSB_cy_m0s8_tcpwm_1__PERIOD )
#define PRS_LSB_PERIOD_PTR                     ( (reg32 *) PRS_LSB_cy_m0s8_tcpwm_1__PERIOD )
#define PRS_LSB_PERIOD_BUF_REG                 (*(reg32 *) PRS_LSB_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define PRS_LSB_PERIOD_BUF_PTR                 ( (reg32 *) PRS_LSB_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define PRS_LSB_TRIG_CONTROL0_REG              (*(reg32 *) PRS_LSB_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define PRS_LSB_TRIG_CONTROL0_PTR              ( (reg32 *) PRS_LSB_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define PRS_LSB_TRIG_CONTROL1_REG              (*(reg32 *) PRS_LSB_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define PRS_LSB_TRIG_CONTROL1_PTR              ( (reg32 *) PRS_LSB_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define PRS_LSB_TRIG_CONTROL2_REG              (*(reg32 *) PRS_LSB_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define PRS_LSB_TRIG_CONTROL2_PTR              ( (reg32 *) PRS_LSB_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define PRS_LSB_INTERRUPT_REQ_REG              (*(reg32 *) PRS_LSB_cy_m0s8_tcpwm_1__INTR )
#define PRS_LSB_INTERRUPT_REQ_PTR              ( (reg32 *) PRS_LSB_cy_m0s8_tcpwm_1__INTR )
#define PRS_LSB_INTERRUPT_SET_REG              (*(reg32 *) PRS_LSB_cy_m0s8_tcpwm_1__INTR_SET )
#define PRS_LSB_INTERRUPT_SET_PTR              ( (reg32 *) PRS_LSB_cy_m0s8_tcpwm_1__INTR_SET )
#define PRS_LSB_INTERRUPT_MASK_REG             (*(reg32 *) PRS_LSB_cy_m0s8_tcpwm_1__INTR_MASK )
#define PRS_LSB_INTERRUPT_MASK_PTR             ( (reg32 *) PRS_LSB_cy_m0s8_tcpwm_1__INTR_MASK )
#define PRS_LSB_INTERRUPT_MASKED_REG           (*(reg32 *) PRS_LSB_cy_m0s8_tcpwm_1__INTR_MASKED )
#define PRS_LSB_INTERRUPT_MASKED_PTR           ( (reg32 *) PRS_LSB_cy_m0s8_tcpwm_1__INTR_MASKED )


/***************************************
*       Registers Constants
***************************************/

/* Mask */
#define PRS_LSB_MASK                           ((uint32)PRS_LSB_cy_m0s8_tcpwm_1__TCPWM_CTRL_MASK)

/* Shift constants for control register */
#define PRS_LSB_RELOAD_CC_SHIFT                (0u)
#define PRS_LSB_RELOAD_PERIOD_SHIFT            (1u)
#define PRS_LSB_PWM_SYNC_KILL_SHIFT            (2u)
#define PRS_LSB_PWM_STOP_KILL_SHIFT            (3u)
#define PRS_LSB_PRESCALER_SHIFT                (8u)
#define PRS_LSB_UPDOWN_SHIFT                   (16u)
#define PRS_LSB_ONESHOT_SHIFT                  (18u)
#define PRS_LSB_QUAD_MODE_SHIFT                (20u)
#define PRS_LSB_INV_OUT_SHIFT                  (20u)
#define PRS_LSB_INV_COMPL_OUT_SHIFT            (21u)
#define PRS_LSB_MODE_SHIFT                     (24u)

/* Mask constants for control register */
#define PRS_LSB_RELOAD_CC_MASK                 ((uint32)(PRS_LSB_1BIT_MASK        <<  \
                                                                            PRS_LSB_RELOAD_CC_SHIFT))
#define PRS_LSB_RELOAD_PERIOD_MASK             ((uint32)(PRS_LSB_1BIT_MASK        <<  \
                                                                            PRS_LSB_RELOAD_PERIOD_SHIFT))
#define PRS_LSB_PWM_SYNC_KILL_MASK             ((uint32)(PRS_LSB_1BIT_MASK        <<  \
                                                                            PRS_LSB_PWM_SYNC_KILL_SHIFT))
#define PRS_LSB_PWM_STOP_KILL_MASK             ((uint32)(PRS_LSB_1BIT_MASK        <<  \
                                                                            PRS_LSB_PWM_STOP_KILL_SHIFT))
#define PRS_LSB_PRESCALER_MASK                 ((uint32)(PRS_LSB_8BIT_MASK        <<  \
                                                                            PRS_LSB_PRESCALER_SHIFT))
#define PRS_LSB_UPDOWN_MASK                    ((uint32)(PRS_LSB_2BIT_MASK        <<  \
                                                                            PRS_LSB_UPDOWN_SHIFT))
#define PRS_LSB_ONESHOT_MASK                   ((uint32)(PRS_LSB_1BIT_MASK        <<  \
                                                                            PRS_LSB_ONESHOT_SHIFT))
#define PRS_LSB_QUAD_MODE_MASK                 ((uint32)(PRS_LSB_3BIT_MASK        <<  \
                                                                            PRS_LSB_QUAD_MODE_SHIFT))
#define PRS_LSB_INV_OUT_MASK                   ((uint32)(PRS_LSB_2BIT_MASK        <<  \
                                                                            PRS_LSB_INV_OUT_SHIFT))
#define PRS_LSB_MODE_MASK                      ((uint32)(PRS_LSB_3BIT_MASK        <<  \
                                                                            PRS_LSB_MODE_SHIFT))

/* Shift constants for trigger control register 1 */
#define PRS_LSB_CAPTURE_SHIFT                  (0u)
#define PRS_LSB_COUNT_SHIFT                    (2u)
#define PRS_LSB_RELOAD_SHIFT                   (4u)
#define PRS_LSB_STOP_SHIFT                     (6u)
#define PRS_LSB_START_SHIFT                    (8u)

/* Mask constants for trigger control register 1 */
#define PRS_LSB_CAPTURE_MASK                   ((uint32)(PRS_LSB_2BIT_MASK        <<  \
                                                                  PRS_LSB_CAPTURE_SHIFT))
#define PRS_LSB_COUNT_MASK                     ((uint32)(PRS_LSB_2BIT_MASK        <<  \
                                                                  PRS_LSB_COUNT_SHIFT))
#define PRS_LSB_RELOAD_MASK                    ((uint32)(PRS_LSB_2BIT_MASK        <<  \
                                                                  PRS_LSB_RELOAD_SHIFT))
#define PRS_LSB_STOP_MASK                      ((uint32)(PRS_LSB_2BIT_MASK        <<  \
                                                                  PRS_LSB_STOP_SHIFT))
#define PRS_LSB_START_MASK                     ((uint32)(PRS_LSB_2BIT_MASK        <<  \
                                                                  PRS_LSB_START_SHIFT))

/* MASK */
#define PRS_LSB_1BIT_MASK                      ((uint32)0x01u)
#define PRS_LSB_2BIT_MASK                      ((uint32)0x03u)
#define PRS_LSB_3BIT_MASK                      ((uint32)0x07u)
#define PRS_LSB_6BIT_MASK                      ((uint32)0x3Fu)
#define PRS_LSB_8BIT_MASK                      ((uint32)0xFFu)
#define PRS_LSB_16BIT_MASK                     ((uint32)0xFFFFu)

/* Shift constant for status register */
#define PRS_LSB_RUNNING_STATUS_SHIFT           (30u)


/***************************************
*    Initial Constants
***************************************/

#define PRS_LSB_CTRL_QUAD_BASE_CONFIG                                                          \
        (((uint32)(PRS_LSB_QUAD_ENCODING_MODES     << PRS_LSB_QUAD_MODE_SHIFT))       |\
         ((uint32)(PRS_LSB_CONFIG                  << PRS_LSB_MODE_SHIFT)))

#define PRS_LSB_CTRL_PWM_BASE_CONFIG                                                           \
        (((uint32)(PRS_LSB_PWM_STOP_EVENT          << PRS_LSB_PWM_STOP_KILL_SHIFT))   |\
         ((uint32)(PRS_LSB_PWM_OUT_INVERT          << PRS_LSB_INV_OUT_SHIFT))         |\
         ((uint32)(PRS_LSB_PWM_OUT_N_INVERT        << PRS_LSB_INV_COMPL_OUT_SHIFT))   |\
         ((uint32)(PRS_LSB_PWM_MODE                << PRS_LSB_MODE_SHIFT)))

#define PRS_LSB_CTRL_PWM_RUN_MODE                                                              \
            ((uint32)(PRS_LSB_PWM_RUN_MODE         << PRS_LSB_ONESHOT_SHIFT))
            
#define PRS_LSB_CTRL_PWM_ALIGN                                                                 \
            ((uint32)(PRS_LSB_PWM_ALIGN            << PRS_LSB_UPDOWN_SHIFT))

#define PRS_LSB_CTRL_PWM_KILL_EVENT                                                            \
             ((uint32)(PRS_LSB_PWM_KILL_EVENT      << PRS_LSB_PWM_SYNC_KILL_SHIFT))

#define PRS_LSB_CTRL_PWM_DEAD_TIME_CYCLE                                                       \
            ((uint32)(PRS_LSB_PWM_DEAD_TIME_CYCLE  << PRS_LSB_PRESCALER_SHIFT))

#define PRS_LSB_CTRL_PWM_PRESCALER                                                             \
            ((uint32)(PRS_LSB_PWM_PRESCALER        << PRS_LSB_PRESCALER_SHIFT))

#define PRS_LSB_CTRL_TIMER_BASE_CONFIG                                                         \
        (((uint32)(PRS_LSB_TC_PRESCALER            << PRS_LSB_PRESCALER_SHIFT))       |\
         ((uint32)(PRS_LSB_TC_COUNTER_MODE         << PRS_LSB_UPDOWN_SHIFT))          |\
         ((uint32)(PRS_LSB_TC_RUN_MODE             << PRS_LSB_ONESHOT_SHIFT))         |\
         ((uint32)(PRS_LSB_TC_COMP_CAP_MODE        << PRS_LSB_MODE_SHIFT)))
        
#define PRS_LSB_QUAD_SIGNALS_MODES                                                             \
        (((uint32)(PRS_LSB_QUAD_PHIA_SIGNAL_MODE   << PRS_LSB_COUNT_SHIFT))           |\
         ((uint32)(PRS_LSB_QUAD_INDEX_SIGNAL_MODE  << PRS_LSB_RELOAD_SHIFT))          |\
         ((uint32)(PRS_LSB_QUAD_STOP_SIGNAL_MODE   << PRS_LSB_STOP_SHIFT))            |\
         ((uint32)(PRS_LSB_QUAD_PHIB_SIGNAL_MODE   << PRS_LSB_START_SHIFT)))

#define PRS_LSB_PWM_SIGNALS_MODES                                                              \
        (((uint32)(PRS_LSB_PWM_SWITCH_SIGNAL_MODE  << PRS_LSB_CAPTURE_SHIFT))         |\
         ((uint32)(PRS_LSB_PWM_COUNT_SIGNAL_MODE   << PRS_LSB_COUNT_SHIFT))           |\
         ((uint32)(PRS_LSB_PWM_RELOAD_SIGNAL_MODE  << PRS_LSB_RELOAD_SHIFT))          |\
         ((uint32)(PRS_LSB_PWM_STOP_SIGNAL_MODE    << PRS_LSB_STOP_SHIFT))            |\
         ((uint32)(PRS_LSB_PWM_START_SIGNAL_MODE   << PRS_LSB_START_SHIFT)))

#define PRS_LSB_TIMER_SIGNALS_MODES                                                            \
        (((uint32)(PRS_LSB_TC_CAPTURE_SIGNAL_MODE  << PRS_LSB_CAPTURE_SHIFT))         |\
         ((uint32)(PRS_LSB_TC_COUNT_SIGNAL_MODE    << PRS_LSB_COUNT_SHIFT))           |\
         ((uint32)(PRS_LSB_TC_RELOAD_SIGNAL_MODE   << PRS_LSB_RELOAD_SHIFT))          |\
         ((uint32)(PRS_LSB_TC_STOP_SIGNAL_MODE     << PRS_LSB_STOP_SHIFT))            |\
         ((uint32)(PRS_LSB_TC_START_SIGNAL_MODE    << PRS_LSB_START_SHIFT)))
        
#define PRS_LSB_TIMER_UPDOWN_CNT_USED                                                          \
                ((PRS_LSB__COUNT_UPDOWN0 == PRS_LSB_TC_COUNTER_MODE)                  ||\
                 (PRS_LSB__COUNT_UPDOWN1 == PRS_LSB_TC_COUNTER_MODE))

#define PRS_LSB_PWM_UPDOWN_CNT_USED                                                            \
                ((PRS_LSB__CENTER == PRS_LSB_PWM_ALIGN)                               ||\
                 (PRS_LSB__ASYMMETRIC == PRS_LSB_PWM_ALIGN))               
        
#define PRS_LSB_PWM_PR_INIT_VALUE              (1u)
#define PRS_LSB_QUAD_PERIOD_INIT_VALUE         (0x8000u)



#endif /* End CY_TCPWM_PRS_LSB_H */

/* [] END OF FILE */
